import qualified MegaModule as M
  ( Either,
    Monad
      ( return,
        (>>),
        (>>=)
      ),
    (<<<),
    (>>>),
  )
